import React from 'react';

import { Collapse, NavLink as BsNavLink } from 'reactstrap';
import { NavLink } from 'react-router-dom';

interface Props {
    sideBarRoutes: any;
}

interface State {
  activeSubMenu: any;
}

export default class SideBar extends React.PureComponent<Props, State> {
  constructor(props: any) {
    super(props);
    this.toggle = this.toggle.bind(this);
    this.state = { activeSubMenu: undefined };
  }

  toggle(e: number) {
    if (this.state.activeSubMenu === e) {
      this.setState({
        activeSubMenu: undefined,
      });
    } else {
      this.setState({
        activeSubMenu: e,
      });
    }
  }

  render() {
    return (
      <nav className="sidebar">
        <div>
          <a className="logo text-center">Logo</a>
          <ul className="sidebar-nav">
            {this.props.sideBarRoutes.map((v, k) => {
              if (v.submenus) {
                return (
                  <li className="sidebar-nav-item" key={k}>
                    <BsNavLink
                      className="sidebar-nav-link"
                      onClick={() => this.toggle(v.index)}
                    >
                      <i className={`nav-link-icon mdi ${v.icon}`} />
                      <span className="va-sub">{v.label}</span>
                      {this.state.activeSubMenu === v.index ? (
                        <i className="mdi mdi-chevron-down" />
                      ) : (
                        <i className="mdi mdi-chevron-right" />
                      )}
                    </BsNavLink>
                    <Collapse isOpen={this.state.activeSubMenu === v.index}>
                      <ul className="sidebar-nav-submenu">
                        {v.submenus.map((v1, k1) => {
                          return (
                            <li key={k1} className="sidebar-nav-item">
                              <NavLink
                                to={v1.path}
                                className="sidebar-nav-link"
                              >
                                <span className="va-sub">{v1.label}</span>
                              </NavLink>
                            </li>
                          );
                        })}
                      </ul>
                    </Collapse>
                  </li>
                );
              } else {
                return (
                  <li className="sidebar-nav-item" key={k}>
                    <NavLink
                      to={v.path}
                      className="sidebar-nav-link"
                      onClick={() => this.toggle(v.index)}
                    >
                      <i className={`nav-link-icon mdi ${v.icon}`} />
                      <span className="va-sub">{v.label}</span>
                    </NavLink>
                  </li>
                );
              }
            })}
          </ul>
        </div>
      </nav>
    );
  }
}
