import React from 'react';
import { Modal, ModalHeader, ModalBody } from 'reactstrap';

import BootstrapTable from 'react-bootstrap-table-next';

import paginationFactory from 'react-bootstrap-table2-paginator';
import ToolkitProvider, {
  Search,
  ColumnToggle,
} from 'react-bootstrap-table2-toolkit';

import { FaCog } from 'react-icons/fa';
import _ from 'lodash';

import ActionButton from './ActionButton';


import { ContextMenu, MenuItem, ContextMenuTrigger } from 'react-contextmenu';

import Hotkeys from 'react-hot-keys';

import { FaPlus, FaPencilAlt, FaTimes } from 'react-icons/fa';

const { CustomToggleList } = ColumnToggle;

const { SearchBar } = Search;
var rows = [];


interface Props {
  key?: string;
  name: string;
  keyField: string;
  checkAll?: true | false;
  pagination?: true | false;
  data: Array<any>;
  columns: Array<any>;
  selectAll: {
    mode: string;
    clickToSelect?: boolean;
    onSelect?: Function;
  };
  actionButtons?: any;
  bordered?: true | false;
  showHotKey?: boolean;
  getData?: Function;
  createBtnOnClick?: () => void;
  editBtnOnClick?: () => void;
  deleteBtnOnClick?: () => void;
}

class BootstrapTableNext extends React.PureComponent<Props, any> {
  static defaultProps = {
    key: 'account_id',
    checkAll: false,
    pagination: true,
    selectAll: {
      mode: 'checkbox',
      clickToSelect: true,
    },
    bordered: false,
  };
  constructor(props: Props) {
    super(props);
    this.toggle = this.toggle.bind(this);
    this.state = {
      modal: false,
      toggle: false,
      myColumns: {
        key: this.props.keyField,
        column: _.map(this.props.columns, 'dataField'),
      },
      editModal: false,
      editToggle: false,
      rows: rows,
    };
  }

  toggle() {
    this.setState({
      toggle: !this.state.toggle,
      modal: !this.state.modal,
    });
  }

  onColumnToggle(data) {
    let myCookieVal = {
      [this.props.name]: this.props.name,
      value: [],
    };
    if (data.toggle) {
      _.remove(this.state.myColumns.column, function(el) {
        // remove column
        return el === data.dataField;
      });
      myCookieVal.value = this.state.myColumns.column;
      //setCookie(getCookie('username'), this.props.name, [myCookieVal]);
    } else {
      this.state.myColumns.column.push(data.dataField);
      myCookieVal.value = this.state.myColumns.column;
      //setCookie(getCookie('username'), this.props.name, [myCookieVal]);
    }
  }

  sendData = (row, isSelect, rowIndex, _e) => {
    this.props.getData
      ? this.props.getData(row, isSelect, rowIndex, this.props.columns)
      : console.log('Function is missing');
  };

  handleClick(row, _isSelect, _rowIndex, columns) {
    var rows = [];
    rows.push(row);
    this.setState({ rows: rows, columns: columns });
  }

  rowEvents = {
    onContextMenu: (e, row, rowIndex) => {
      this.props.getData
        ? this.props.getData(row, '0', rowIndex, this.props.columns)
        : console.log('Function is missing');
      e.preventDefault();
    },
    onMouseLeave: () => {
      this.setState({ hoverIdx: null });
    },
  };

  onKeyUp(_keyName, _e, handle) {
    if (handle.shortcut === 'alt+s') {
      this.toggle();
    }
  }

  onKeyDown(_keyName, _e, _handle) {}

  render() {
    const options = {
      showTotal: true,
    };

    const selectRow = {
      mode: 'checkbox',
      clickToSelect: true,
      onSelect: this.sendData,
    };

    return (
      <div>
        <ToolkitProvider
          keyField={this.props.keyField ? this.props.keyField : 'id'}
          data={this.props.data}
          columns={this.props.columns}
          search
          columnToggle
        >
          {props => (
            <div>
              <div className="row">
                <div className="col-md-3">
                  <SearchBar className="input-style" {...props.searchProps} />
                </div>
                <div className="col-md-8 action-buttons-bottom">
                  {this.props.actionButtons ? (
                    <ActionButton
                      btnClass=""
                      actionBtn={this.props.actionButtons}
                      showHotKey={this.props.showHotKey}
                      createBtnOnClick={this.props.createBtnOnClick}
                      editBtnOnClick={this.props.editBtnOnClick}
                      deleteBtnOnClick={this.props.deleteBtnOnClick}
                    />
                  ) : (
                    ''
                  )}
                </div>
                <div className="col-md-1 d-flex justify-content-end">
                  <div className="hot-key-settings">
                    {this.props.showHotKey ? (
                      <text className="hot-key">S</text>
                    ) : null}
                  </div>
                  <FaCog onClick={this.toggle} />
                </div>
              </div>

              <ContextMenuTrigger id="some_unique_identifier">
                <BootstrapTable
                  {...props.baseProps}
                  keyField={this.props.keyField ? this.props.keyField : 'id'}
                  data={this.props.data}
                  columns={this.props.columns}
                  striped
                  hover
                  condensed
                  bootstrap4
                  pagination={paginationFactory(options)}
                  selectRow={selectRow}
                  noDataIndication="No Data to Show"
                  wrapperClasses="table-responsive"
                  bordered={this.props.bordered}
                  filterPosition="top"
                  rowEvents={this.rowEvents}
                />
              </ContextMenuTrigger>

              <ContextMenu id="some_unique_identifier">
                <MenuItem
                  data={{ foo: 'bar' }}
                  onClick={this.props.createBtnOnClick}
                >
                  <FaPlus /> <u>C</u>reate
                </MenuItem>
                <MenuItem
                  data={{ foo: 'bar' }}
                  onClick={this.props.editBtnOnClick}
                >
                  <FaPencilAlt /> <u>E</u>dit
                </MenuItem>
                <MenuItem divider />
                <MenuItem
                  data={{ foo: 'bar' }}
                  onClick={this.props.deleteBtnOnClick}
                >
                  <FaTimes /> <u>D</u>elete
                </MenuItem>
              </ContextMenu>

              <Hotkeys
                keyName="alt+s"
                onKeyDown={this.onKeyDown.bind(this)}
                onKeyUp={this.onKeyUp.bind(this)}
              >
                <Modal isOpen={this.state.modal} toggle={this.toggle} size="xl">
                  <ModalHeader toggle={this.toggle}>
                    Column Settings
                  </ModalHeader>
                  <ModalBody className="toggle-col">
                    <CustomToggleList {...props.columnToggleProps} />
                  </ModalBody>
                </Modal>
              </Hotkeys>
            </div>
          )}
        </ToolkitProvider>
      </div>
    );
  }
}
export default BootstrapTableNext;
