import React from 'react';
import 'react-virtualized/styles.css';
import { IoMdCheckmark } from 'react-icons/io';
import { Table } from 'react-virtualized';
import _ from 'lodash';
import { FaSort, FaSortUp, FaSortDown } from 'react-icons/fa';
import { MdClose } from 'react-icons/md';
import { ContextMenu, MenuItem, ContextMenuTrigger } from 'react-contextmenu';
import { FaPencilAlt, FaTimes } from 'react-icons/fa';

interface Props {
  data: Array<any>;
  headers: Array<any>;
  form?: any;
  showHotKey?: boolean;
  isEdit?: boolean;
  isDelete?: boolean;
  showContextMenu?: boolean;
  actionButtons?: any;
  bordered?: true | false;
  onScroll?: Function;
  onEdit?: Function;
  onDelete?: Function;
  getData?: Function;
  getRow?: Function;
  updateTable?: Function;
  contextMenuEditModal?: Function;
}
interface State {
  data: Array<any>;
  headers: Array<any>;
  rowData: any;
  sortDirection: any;
  sortedColumn: string;
  row: any;
  column: any;
  editedValue: string;
  rowIndex: any;
  sorted: boolean;
}

export default class VirtualizedTable extends React.PureComponent<
  Props,
  State,
  any
  > {
  constructor(props: Props) {
    super(props);
    console.log(this.props);
    this.state = {
      data: this.props.data,
      headers: this.props.headers,
      rowData: [],
      sortDirection: 'asc',
      sortedColumn: '',
      row: '',
      column: '',
      editedValue: '',
      rowIndex: '',
      sorted: false,
    };
  }

  componentDidUpdate() {
    if (!this.state.sorted) {
      this.setState({
        data: this.props.data,
        headers: this.props.headers,
      });
    }
  }

  transform = (row, column) => {
    this.setState({ row: row, column: column });
  };

  cancel = () => {
    this.setState({ row: '', column: '' });
  };

  edit = (column_index, index) => {
    var data = [...this.state.data];
    data[index][this.state.headers[column_index].dataField] = this.state.editedValue;
    this.setState({ row: '', column: '', data: data });
    // this.props.onEdit(id, column_index, index, this.state.editedValue);
  };

  handleEdit = event => {
    this.setState({ editedValue: event.target.value });
  };

  sort = sortBy => {
    var dataSet = [...this.state.data];
    const sortedData = _.orderBy(dataSet, sortBy, this.state.sortDirection);
    if (this.state.sortDirection === 'asc') {
      this.setState(
        {
          data: sortedData,
          sortDirection: 'desc',
          sortedColumn: sortBy,
          sorted: true
        },
        () => this.props.updateTable ? this.props.updateTable(this.state.data) : console.log('No function defined')
      );
    } else {
      this.setState(
        {
          data: sortedData,
          sortDirection: 'asc',
          sortedColumn: sortBy,
          sorted: true
        },
        () => this.props.updateTable ? this.props.updateTable(this.state.data) : console.log('No function defined')
      );
    }
  };

  getRowData = props => {
    this.setState({
      rowData: props.rowData,
      rowIndex: props.index,
    });
  };

  renderTable = values => {
    var dataSet = [...this.state.data];
    this.state.headers.forEach(header => {
      if (values[header] !== undefined) {
        dataSet[this.state.rowIndex][header] = values[header];
      }
    });
    this.setState({ data: dataSet });
    this.props.updateTable ? this.props.updateTable(this.state.data) : console.log('No function defined');
  };

  renderRow = props => {
    return (
      <div
        style={props.style}
        className="d-flex flex-row"
        onContextMenu={() => this.props.getRow ? this.props.getRow(props) : console.log('No data')}
      >
        <input
          type="checkbox"
          style={{ flex: '0 1 100px', marginTop: '12px' }}
          onClick={() => this.props.getRow ? this.props.getRow(props) : console.log('No data')}
        />
        {Object.values(props.rowData).map((cell, index) => {
          if (
            this.state.row === props.rowData.id &&
            this.state.column === index
          ) {
            var data = String(cell);
            return (
              <span className="table-row">
                <input
                  type="text"
                  defaultValue={data}
                  className="transformed-input-style"
                  style={{ width: '120px' }}
                  onChange={event => this.handleEdit(event)}
                />
                <IoMdCheckmark
                  className="icon"
                  onClick={() =>
                    this.edit(index, props.index)
                  }
                />
                <MdClose className="icon" onClick={() => this.cancel()} />
              </span>
            );
          } else {
            return (
              <span
                className="table-row"
                onDoubleClick={() => this.transform(props.rowData.id, index)}
              >
                {cell}
              </span>
            );
          }
        })}
      </div>
    );
  };

  renderHeader = props => {
    return (
      <>
        <div
          style={props.style}
          className="ReactVirtualized__Table__headerRow header"
        >
          <input
            type="checkbox"
            style={{ flex: '0 1 100px', visibility: 'hidden' }}
          />
          {this.state.headers.map(header => {
            return (
              <span className="table-row" onClick={() => this.sort(header.dataField)}>
                {header.text}
                {this.state.sortedColumn === header.dataField ? (
                  this.state.sortDirection === 'asc' ? (
                    <FaSortDown className="margin-left-10" />
                  ) : (
                      <FaSortUp className="margin-left-10" />
                    )
                ) : (
                    <FaSort className="margin-left-10" />
                  )}
              </span>
            )
          })}
        </div>
      </>
    );
  };

  noScroll = () => {
    console.log('No scroll method found');
  };

  render() {
    return (
      <div>
        <ContextMenuTrigger id="some_unique_identifier">
          <Table
            width={2000}
            height={585}
            headerHeight={20}
            headerClassName="header"
            rowHeight={40}
            rowCount={this.state.data.length}
            rowGetter={({ index }) => this.state.data[index]}
            onScroll={this.props.onScroll ? this.props.onScroll() : this.noScroll}
            isScrolling={true}
            rowRenderer={this.renderRow}
            headerRowRenderer={this.renderHeader}
          />
        </ContextMenuTrigger>
        {this.props.showContextMenu ? (
          <ContextMenu id="some_unique_identifier">
            {this.props.isEdit ? (
              <MenuItem onClick={this.props.contextMenuEditModal}>
                <FaPencilAlt /> <u>E</u>dit
              </MenuItem>
            ) : null}
            <MenuItem divider />
            {this.props.isDelete ? (
              <MenuItem onClick={this.props.onDelete}>
                <FaTimes /> <u>D</u>elete
              </MenuItem>
            ) : null}
          </ContextMenu>
        ) : null}
      </div>
    );
  }
}
