import React from 'react';

import DynamicForm from './../components/lib/DynamicForm';
import createYupSchema from 'utils/YupSchemaGenerator';
import {  Alert, Toast, Badge, Button, Form, FormGroup, Label, Input, FormText } from 'reactstrap';

import * as Yup from 'yup';

const form = {
buttonPosition: 'right',
    buttons: [
        {
            id: 'reset',
            label: 'Reset Password',
            type: 'button',
            buttonType: 'reset',
            name: 'login-form-reset',
        },
        {
            id: 'submit',
            label: 'Sign in',
            type: 'button',
            buttonType: 'submit',
            name: 'login-form-submit'
        },        
    ]
};

const fields = [
    {
      id: 'username',
      label: 'User Name',
      type: 'text',
      name: 'username',
      value: '',
      placeholder: 'User ID',
      classNames: 'usernametb',
      validations: [
        {
          type: 'required',
          params: ['This field is required'],
        },
      ],
    },
    {
      id: 'password',
      label: 'Password',
      type: 'password',
      name: 'password',
      value: '',
      placeholder: 'Password',
      classNames: 'usernametb',
      validations: [
        {
          type: 'required',
          params: ['This field is required'],
        },
      ],
    },
    {
      id: 'userId',
      classNames: 'usernametb',
      type: 'select',
      name: 'userId',
      value: [],
      options: [
        { value: '400/US01-000005673', label: '400/US01-000005673)' },
        { value: '400/US01-000005674', label: '400/US01-000005674' },
        { value: '400/US01-000005675', label: '400/US01-000005675' },
      ],
      validations: [
        {
          type: 'required',
          params: ['This field is required'],
        },
      ],
    },
];

const inputFields = [
  {
    id: 'inputText',
    label: 'InputText',
    type: 'text',
    name: 'inputText',
    value: '',
    validations: [
      {
        type: 'required',
        params: ['This field is required'],
      },
    ],
  },
  {
    id: 'password',
    label: 'Password',
    type: 'password',
    name: 'password',
    value: '',
    validations: [
      {
        type: 'required',
        params: ['This field is required'],
      }
    ],
  },
  {
    id: 'inputNumber',
    label: 'InputNumber',
    type: 'number',
    name: 'inputNumber',
    value: '',
    validations: [
      {
        type: 'required',
        params: ['This field is required'],
      }
    ],
  },
  {
    id: 'inputEmail',
    label: 'InputEmail',
    type: 'email',
    name: 'inputEmail',
    value: '',
    validations: [
      {
        type: 'required',
        params: ['This field is required'],
      },
      {
        type: 'email',
        params: ['Invalid Email format'],
      },
    ],
  },
  {
    id: 'inputToggle',
    label: 'InputToggle',
    type: 'toggle',
    name: 'inputToggle',
    value: '',
    validations: [
      {
        type: 'required',
        params: ['This field is required'],
      }
    ],
  },
];

const checkboxFields = [
  {
    id: 'checkbox',
    label: 'Checkbox',
    type: 'checkbox',
    name: 'checkbox',
    value: '',
    validations: [
      {
        type: 'required',
        params: ['This field is required'],
      }
    ],
  },
  {
    id: 'checkbox_group',
    label: 'Checkbox group',
    type: 'checkbox_group',
    name: 'checkbox_group',
    position: 'grid',
    positionGrid: 4,
    value: [],
    options: [
      { id: 'en', value: 'en', label: 'English', disabled: true },
      { id: 'tamil', value: 'tamil', label: 'Tamil' },
      { id: 'telugu', value: 'telugu', label: 'Telugu' },
    ],
    validations: [
      {
        type: 'required',
        params: ['This field is required'],
      },
    ],
  },
];

const radioFields = [
  {
    id: 'radio',
    label: 'Radio button',
    type: 'radio',
    name: 'radio',
    value: '',
    position: 'inline',
    options: [
      { id: 'india', value: 'india', label: 'India' },
      { id: 'us', value: 'us', label: 'US' },
      { id: 'uk', value: 'uk', label: 'UK' },
      { id: 'europe', value: 'europe', label: 'Europe' },
    ],
    validations: [
      {
        type: 'required',
        params: ['This field is required'],
      },
    ],
  },
];

const textareaFields = [
  {
    id: 'textarea',
    label: 'Text area',
    type: 'textarea',
    name: 'textarea',
    value: '',
    validations: [
      {
        type: 'required',
        params: ['This field is required'],
      },
    ],
  },
];

const searchFields = [
  {
    id: 'array_fields',
    label: 'Array fields',
    type: 'array_fields',
    name: 'array_fields',
    value: [{ myName: '', age: '', country: '' }],
    isArrayField: true,
    arrayFields: {
      headers: [
        { label: 'Name', width: 33, key: 'myName', required: true },
        { label: 'Age', width: 20, key: 'age', required: true },
        { label: 'Countries', width: 20, key: 'country', required: true },
      ],
      fields: [
        {
          name: 'myName',
          type: 'text',
          id: 'myName',
          validations: [
            {
              type: 'required',
              params: ['This field is required'],
            },
            {
              type: 'email',
              params: ['Invalid Email format'],
            },
          ],
        },
        {
          name: 'age',
          type: 'text',
          id: 'age',
          validations: [
            {
              type: 'required',
              params: ['This field is required'],
            },
          ],
        },
        {
          type: 'select',
          name: 'country',
          id: 'country',
          value: [],
          options: [
            { value: 'india', label: 'India' },
            { value: 'us', label: 'US' },
            { value: 'uk', label: 'UK' },
            { value: 'europe', label: 'Europe' },
            { value: 'japan', label: 'Japan' },
          ],
          validations: [
            {
              type: 'required',
              params: ['This field is required'],
            },
          ],
        },
      ],
    },
  },
];

function onFormSubmit() {
    // alert("Dynamic Forms")
}

export default {
  title: 'Form Inputs',
  component: DynamicForm,
};

const yepSchema = fields.reduce(createYupSchema, {});
const validateSchema = Yup.object().shape(yepSchema);

export const DynamicForm1 = () => {
  return (
    <div style={{ marginTop: '10px', marginLeft: '10px', marginRight: '10px' }}>
       <DynamicForm
        form={form}
        fields={fields}
        validation={validateSchema}
        onFormSubmit={onFormSubmit()}
        errorPosition="right"
        />
    </div>
  )
};

DynamicForm1.story = {
  name: 'Dynamic Forms',
};

export const TextInputs = () => {
    return (
      <div style={{ marginTop: '10px', marginLeft: '10px' }}>
         <DynamicForm
          key="test-form"
          form={form}
          layout="vertical"
          labelPosition="left"
          fields={inputFields}
          validation={validateSchema}
          onFormSubmit={onFormSubmit}
        />
      </div>
    )
};
  
TextInputs.story = {
    name: 'Text Inputs',
};

export const TextArea = () => {
    return (
    <div style={{ marginTop: '10px', marginLeft: '10px', marginRight: '10px' }}>        
        <FormGroup>
          <Label for="exampleText">Text Area</Label>
          <Input type="textarea" name="text" id="exampleText" />
        </FormGroup>
    </div>
    )
};
    
TextArea.story = {
    name: 'Text Area',
};

export const CheckBox = () => {
    return (
    <div style={{ marginTop: '10px', marginLeft: '10px', marginRight: '10px' }}>
        <DynamicForm
          fields={checkboxFields}
          validation={validateSchema}
          onFormSubmit={onFormSubmit()}
          errorPosition="right"
        />
    </div>
    )
};
    
CheckBox.story = {
    name: 'CheckBox and Group',
};
    
TextArea.story = {
    name: 'Text Area',
};

export const Radio = () => {
    return (
    <div style={{ marginTop: '10px', marginLeft: '10px', marginRight: '10px' }}>
        <DynamicForm
          form=""
          fields={radioFields}
          validation={validateSchema}
          onFormSubmit={onFormSubmit()}
          errorPosition="right"
        />
    </div>
    )
};
    
Radio.story = {
    name: 'Radio',
};

export const Search = () => {
    return (
    <div>
        <DynamicForm
        form=""
        fields={searchFields}
        validation={validateSchema}
        onFormSubmit={onFormSubmit()}
        errorPosition="right"
        />
    </div>
    )
};
    
Search.story = {
    name: 'Search',
};

export const AlertToastBadge = () => {
    return (
    <div style={{ marginTop: '10px', marginLeft: '10px', marginRight: '10px' }}>
      <div>
        <p>Alert</p>
        <Alert color="primary">
          This is a primary alert
        </Alert>
      </div>
      <hr />
      {/* <div>
        <p>Toast</p>
        <Toast>
          <Toast.Header>
            <strong>React-Bootstrap</strong>
            <small>11 mins ago</small>
          </Toast.Header>
          <Toast.Body>Hello, world! This is a toast message.</Toast.Body>
        </Toast>
      </div>
      <hr /> */}
      <div>
        <p>Badge</p>
        <Badge color="primary">New</Badge>
      </div>
    </div>
    )
};
    
AlertToastBadge.story = {
    name: 'Alert/Toast/Badge',
};
  
