import React from 'react';

import DynamicForm from '../components/lib/DynamicForm';
import Select from '../components/lib/Select';
import createYupSchema from 'utils/YupSchemaGenerator';
import * as Yup from 'yup';

const form = {
buttonPosition: 'right',
    buttons: [
        {
            id: 'reset',
            label: 'Reset Password',
            type: 'button',
            buttonType: 'reset',
            name: 'login-form-reset'
        },
        {
            id: 'submit',
            label: 'Sign in',
            type: 'button',
            buttonType: 'submit',
            name: 'login-form-submit'
        },        
    ]
};

const fields = [
    {
      id: 'username',
      label: 'User Name',
      type: 'text',
      name: 'username',
      value: '',
      placeholder: 'User ID',
      classNames: 'usernametb',
      validations: [
        {
          type: 'required',
          params: ['This field is required'],
        },
      ],
    },
    {
      id: 'password',
      label: 'Password',
      type: 'password',
      name: 'password',
      value: '',
      placeholder: 'Password',
      classNames: 'usernametb',
      validations: [
        {
          type: 'required',
          params: ['This field is required'],
        },
      ],
    },
    {
      id: 'userId',
      classNames: 'usernametb',
      type: 'select',
      name: 'userId',
      value: [],
      options: [
        { value: '400/US01-000005673', label: '400/US01-000005673)' },
        { value: '400/US01-000005674', label: '400/US01-000005674' },
        { value: '400/US01-000005675', label: '400/US01-000005675' },
      ],
      validations: [
        {
          type: 'required',
          params: ['This field is required'],
        },
      ],
    },
];


const selectSingleFields = [
  {
    id: 'select',
    label: 'Select',
    type: 'select',
    name: 'select',
    isMulti: false,
    options: [
      { id: '1', value: '1', label: 'India' },
      { id: '2', value: '2', label: 'UK' },
      { id: '3', value: '3', label: 'US' },
      { id: '4', value: '4', label: 'Europe' },
    ],
    validations: [
      {
        type: 'required',
        params: ['This field is required'],
      },
    ],
  },
];
const selectMultiFields = [
  {
    id: 'multi_select',
    label: 'Multi select',
    type: 'multi_select',
    name: 'multi_select',
    value: [],
    isMulti: true,
    options: [
      { value: 'india', label: 'India' },
      { value: 'us', label: 'US' },
      { value: 'uk', label: 'UK' },
    ],
    validations: [
      {
        type: 'required',
        params: ['This field is required'],
      },
    ],
  },
];

function onFormSubmit() {
  // alert("Dynamic Forms")
}

export default {
  title: 'Select',
  component: Select,
};

const yepSchema = fields.reduce(createYupSchema, {});
const validateSchema = Yup.object().shape(yepSchema);

export const SingleSelect = () => {
  return (
    <div style={{ marginTop: '10px', marginLeft: '10px', marginRight: '10px' }}>
       <DynamicForm
        form=""
        fields={selectSingleFields}
        validation={validateSchema}
        onFormSubmit={onFormSubmit()}
        errorPosition="right"
        />
    </div>
  )
};

SingleSelect.story = {
  name: 'Single Select',
};

export const MultiSelect = () => {
  return (
    <div style={{ marginTop: '10px', marginLeft: '10px', marginRight: '10px' }}>
       <DynamicForm
        form=""
        fields={selectMultiFields}
        validation={validateSchema}
        onFormSubmit={onFormSubmit()}
        errorPosition="right"
        />
    </div>
  )
};

MultiSelect.story = {
  name: 'Multi Select',
};