import React from 'react';

import DynamicForm from '../components/lib/DynamicForm';
import DatePicker from '../components/lib/DatePicker';
import Select from '../components/lib/Select';
import createYupSchema from 'utils/YupSchemaGenerator';
import * as Yup from 'yup';

import 'bootstrap/dist/css/bootstrap.min.css';
import 'react-datepicker/dist/react-datepicker.css';

import './../index.css';
import './../custom.scss';

const form = {
buttonPosition: 'right',
    buttons: [
        {
            id: 'reset',
            label: 'Reset Password',
            type: 'button',
            buttonType: 'reset',
            name: 'login-form-reset',
            classNames: 'resetPassword',
        },
        {
            id: 'submit',
            label: 'Sign in',
            type: 'button',
            buttonType: 'submit',
            name: 'login-form-submit',
            classNames: 'btn btn-primary loginFields shadow-lg',
        },        
    ]
};


const dateFields = [
  {
    id: 'datepicker',
    label: 'Datepicker',
    type: 'datepicker',
    name: 'datepicker',
    value: '',
    validations: [
      {
        type: 'required',
        params: ['This field is required'],
      }
    ],
  },
  {
    id: 'timepicker',
    label: 'Timepicker',
    type: 'timepicker',
    name: 'timepicker',
    value: '',
    validations: [
      {
        type: 'required',
        params: ['This field is required'],
      }
    ],
  },
];

function onFormSubmit() {
  // alert("Dynamic Forms")
}

export default {
  title: 'Date and Time',
  component: DatePicker,
};

const yepSchema = dateFields.reduce(createYupSchema, {});
const validateSchema = Yup.object().shape(yepSchema);

export const DateSelector = () => {
  return (
    <div style={{ marginTop: '10px', marginLeft: '10px', marginRight: '10px' }}>
       <DynamicForm
        form=""
        fields={dateFields}
        validation={validateSchema}
        onFormSubmit={onFormSubmit()}
        errorPosition="right"
        />
    </div>
  )
};

DateSelector.story = {
  name: 'Date Picker',
};

export const TimeSelector = () => {
  return (
    <div style={{ marginTop: '10px', marginLeft: '10px', marginRight: '10px' }}>
       <DynamicForm
        form=""
        fields={dateFields}
        validation={validateSchema}
        onFormSubmit={onFormSubmit()}
        errorPosition="right"
        />
    </div>
  )
};

TimeSelector.story = {
  name: 'Time Picker',
};