import React from 'react';

import DynamicForm from '../components/lib/DynamicForm';
import Button from '../components/lib/Button';
import createYupSchema from 'utils/YupSchemaGenerator';
import * as Yup from 'yup';

const form = {
buttonPosition: 'right',
    buttons: [
        {
            id: 'reset',
            label: 'Reset Password',
            type: 'button',
            buttonType: 'reset',
            name: 'login-form-reset',
            classNames: 'resetPassword',
        },
        {
            id: 'submit',
            label: 'Sign in',
            type: 'button',
            buttonType: 'submit',
            name: 'login-form-submit',
            classNames: 'btn btn-primary loginFields shadow-lg',
        },        
    ]
};

const fields = [
    {
      id: 'username',
      label: 'User Name',
      type: 'text',
      name: 'username',
      value: '',
      placeholder: 'User ID',
      classNames: 'usernametb',
      validations: [
        {
          type: 'required',
          params: ['This field is required'],
        },
      ],
    },
    {
      id: 'password',
      label: 'Password',
      type: 'password',
      name: 'password',
      value: '',
      placeholder: 'Password',
      classNames: 'usernametb',
      validations: [
        {
          type: 'required',
          params: ['This field is required'],
        },
      ],
    },
    {
      id: 'userId',
      classNames: 'usernametb',
      type: 'select',
      name: 'userId',
      value: [],
      options: [
        { value: '400/US01-000005673', label: '400/US01-000005673)' },
        { value: '400/US01-000005674', label: '400/US01-000005674' },
        { value: '400/US01-000005675', label: '400/US01-000005675' },
      ],
      validations: [
        {
          type: 'required',
          params: ['This field is required'],
        },
      ],
    },
];

const data = {
  name: 'IBR',
  keyField: 'id',
  data: [
    {
      id: 1,
      transport_method: 'DHL',
      date: 'Feb 12 2020 18:08:43',
      container_count: 20,
      status: 'In-Process',
      receipt_id: '400/US01-000005673',
      location: 'US01-VA03',
    },
    {
      id: 2,
      transport_method: 'DHL',
      date: 'Feb 12 2020 18:08:43',
      container_count: 40,
      status: 'In-Process',
      receipt_id: '400/US01-000005343',
      location: 'US01-VA03',
    },
    {
      id: 3,
      transport_method: 'DHL',
      date: 'Feb 12 2020 18:08:43',
      container_count: 120,
      status: 'In-Process',
      receipt_id: '400/US01-000005346',
      location: 'US01-VA03',
    },
    {
      id: 4,
      transport_method: 'FedEx',
      date: 'Feb 12 2020 18:08:43',
      container_count: 44,
      status: 'In-Process',
      receipt_id: '400/US01-000005348',
      location: 'US01-VA03',
    },
    {
      id: 5,
      transport_method: 'Ryder',
      date: 'Feb 12 2020 18:08:43',
      container_count: 20,
      status: 'In-Process',
      receipt_id: '400/US01-000005349',
      location: 'US01-VA03',
    },
    {
      id: 6,
      transport_method: 'FedEx',
      date: 'Feb 13 2020 18:08:43',
      container_count: 24,
      status: 'In-Process',
      receipt_id: '400/US01-000005333',
      location: 'US01-VA03',
    },
    {
      id: 7,
      transport_method: 'DHL',
      date: 'Feb 13 2020 18:08:43',
      container_count: 20,
      status: 'New',
      receipt_id: '400/US01-000005334',
      location: 'US01-VA03',
    },
    {
      id: 8,
      transport_method: 'DHL',
      date: 'Feb 13 2020 18:08:43',
      container_count: 30,
      status: 'In-Process',
      receipt_id: '400/US01-000005335',
      location: 'US01-VA03',
    },
    {
      id: 9,
      transport_method: 'FedEx',
      date: 'Feb 13 2020 18:08:43',
      container_count: 20,
      status: 'In-Process',
      receipt_id: '400/US01-000005336',
      location: 'US01-VA03',
    },
    {
      id: 10,
      transport_method: 'Ryder',
      date: 'Feb 13 2020 18:08:43',
      container_count: 22,
      status: 'In-Process',
      receipt_id: '400/US01-000005337',
      location: 'US01-VA03',
    },
    {
      id: 11,
      transport_method: 'DHL',
      date: 'Feb 14 2020 18:08:43',
      container_count: 20,
      status: 'In-Process',
      receipt_id: '400/US01-000005338',
      location: 'US01-VA03',
    },
    {
      id: 12,
      transport_method: 'DHL',
      date: 'Feb 14 2020 18:08:43',
      container_count: 21,
      status: 'In-Process',
      receipt_id: '400/US01-000005338',
      location: 'US01-VA03',
    },
  ],
  columns: [
    {
      dataField: 'id',
      text: 'ID',
      sort: true,
    },
    {
      dataField: 'transport_method',
      text: 'Transport Method',
      sort: true,
      searchable: true,
    },
    {
      dataField: 'date',
      text: 'Received Date',
      sort: true,
    },
    {
      dataField: 'container_count',
      text: 'Container Count',
      sort: true,
    },
    {
      dataField: 'status',
      text: 'Status',
      sort: true,
    },
    {
      dataField: 'receipt_id',
      text: 'Receipt ID',
      sort: true,
    },
    {
      dataField: 'location',
      text: 'Location',
      sort: true,
    },
  ],
};

const tabfields = [
  {
    id: 'Test Tab',
    name: 'Tab',
    type: 'tab',
    tabActive: 'Work Request Information',
    tabList: [
      {
        id: '1',
        title: 'Work Request Information',
        tabcontent: '',
        hasTable: true,
        tableData: data,
      },
      {
        id: '2',
        title: 'Index',
        tabcontent: fields,
        hasTable: false,
        tableData: '',
      },
    ],
  },
];

function onFormSubmit() {
  // alert("Dynamic Forms")
}

export default {
  title: 'TabSet',
  component: TabSet,
};

const yepSchema = fields.reduce(createYupSchema, {});
const validateSchema = Yup.object().shape(yepSchema);

export const TabSet = () => {
  return (
    <div style={{ marginTop: '10px', marginLeft: '10px', marginRight: '10px' }}>
       <DynamicForm
          key="test-form"
          form=""
          layout="vertical"
          labelPosition="left"
          fields={tabfields}
          validation={validateSchema}
          onFormSubmit={onFormSubmit}
        />
    </div>
  )
};

TabSet.story = {
  name: 'Tab Set',
};