import React, { useState } from 'react';
import { Collapse, Card, CardBody, Button, ListGroup, ListGroupItem, Breadcrumb, BreadcrumbItem } from 'reactstrap';

import DynamicForm from '../components/lib/DynamicForm';
import StepZillaWizard from '../components/lib/StepZillaWizard';
import createYupSchema from 'utils/YupSchemaGenerator';
import * as Yup from 'yup';

const form = {
buttonPosition: 'right',
    buttons: [
        {
            id: 'reset',
            label: 'Reset Password',
            type: 'button',
            buttonType: 'reset',
            name: 'login-form-reset',
            classNames: 'resetPassword',
        },
        {
            id: 'submit',
            label: 'Sign in',
            type: 'button',
            buttonType: 'submit',
            name: 'login-form-submit',
            classNames: 'btn btn-primary loginFields shadow-lg',
        },        
    ]
};

const fields = [
    {
      id: 'username',
      label: 'User Name',
      type: 'text',
      name: 'username',
      value: '',
      placeholder: 'User ID',
      classNames: 'usernametb',
      validations: [
        {
          type: 'required',
          params: ['This field is required'],
        },
      ],
    },
    {
      id: 'password',
      label: 'Password',
      type: 'password',
      name: 'password',
      value: '',
      placeholder: 'Password',
      classNames: 'usernametb',
      validations: [
        {
          type: 'required',
          params: ['This field is required'],
        },
      ],
    },
    {
      id: 'userId',
      classNames: 'usernametb',
      type: 'select',
      name: 'userId',
      value: [],
      options: [
        { value: '400/US01-000005673', label: '400/US01-000005673)' },
        { value: '400/US01-000005674', label: '400/US01-000005674' },
        { value: '400/US01-000005675', label: '400/US01-000005675' },
      ],
      validations: [
        {
          type: 'required',
          params: ['This field is required'],
        },
      ],
    },
];

const steps = [
  {
    name: 'Step 1',
    component: (
      <div>
        <label>Enter some data: </label>
        <input type="input" />
      </div>
    ),
  },
  {
    name: 'Step 2',
    component: (
      <div>
        <label>This is step 2: </label>
        <input type="input" />
      </div>
    ),
  },
  {
    name: 'Step 3',
    component: (
      <div>
        <label>Last step: </label>
        <input type="input" />
      </div>
    ),
  },
];

function onFormSubmit() {
  // alert("Dynamic Forms")
}

export default {
  title: 'Collapse',
  component: Collapse,
};

const yepSchema = fields.reduce(createYupSchema, {});
const validateSchema = Yup.object().shape(yepSchema);

// const [isOpen, setIsOpen] = useState(false);
// const toggle = () => setIsOpen(!isOpen);


export const Collapse1 = () => {
  const [isOpen, setIsOpen] = useState(false);
  const toggle = () => setIsOpen(!isOpen);
  return (
    <div style={{ marginTop: '10px', marginLeft: '10px', marginRight: '10px' }}>
      <Button onClick={toggle}>Toggle</Button>
      <Collapse isOpen={isOpen}>
        <Card>
          <CardBody>
            This is some random text
          </CardBody>
        </Card>
      </Collapse>
    </div>
  )
};

Collapse1.story = {
  name: 'Collapse',
};

export const List = () => {
  return (
    <div style={{ marginTop: '10px', marginLeft: '10px', marginRight: '10px' }}>
       <ListGroup>
        <ListGroupItem>Cras justo odio</ListGroupItem>
        <ListGroupItem>Dapibus ac facilisis in</ListGroupItem>
        <ListGroupItem>Morbi leo risus</ListGroupItem>
        <ListGroupItem>Porta ac consectetur ac</ListGroupItem>
        <ListGroupItem>Vestibulum at eros</ListGroupItem>
      </ListGroup>
    </div>
  )
};

List.story = {
  name: 'List',
};

export const Breadcrumb1 = () => {
  return (
    <div style={{ marginTop: '10px', marginLeft: '10px', marginRight: '10px' }}>
       <Breadcrumb tag="nav" listTag="div">
        <BreadcrumbItem tag="a" href="#">Home</BreadcrumbItem>
        <BreadcrumbItem tag="a" href="#">Library</BreadcrumbItem>
        <BreadcrumbItem tag="a" href="#">Data</BreadcrumbItem>
        <BreadcrumbItem active tag="span">Bootstrap</BreadcrumbItem>
      </Breadcrumb>
    </div>
  )
};

Breadcrumb1.story = {
  name: 'Breadcrumb',
};

export const Slider = () => {
  return (
    <div style={{ marginTop: '10px', marginLeft: '10px', marginRight: '10px' }}>
      <input type="range" />
    </div>
  )
};

Slider.story = {
  name: 'Slider',
};

export const FormWizard = () => {
  return (
    <div style={{ marginTop: '10px', marginLeft: '10px', marginRight: '10px' }}>
       <StepZillaWizard steps={steps} />
    </div>
  )
};

FormWizard.story = {
  name: 'Form Wizard',
};