import React from 'react';
import { Navbar } from 'reactstrap';

import DynamicForm from '../components/lib/DynamicForm';
import Header from '../components/layout/Header';
import Footer from '../components/layout/Footer';
import createYupSchema from 'utils/YupSchemaGenerator';
import * as Yup from 'yup';

const form = {
buttonPosition: 'right',
    buttons: [
        {
            id: 'reset',
            label: 'Reset Password',
            type: 'button',
            buttonType: 'reset',
            name: 'login-form-reset',
            classNames: 'resetPassword',
        },
        {
            id: 'submit',
            label: 'Sign in',
            type: 'button',
            buttonType: 'submit',
            name: 'login-form-submit',
            classNames: 'btn btn-primary loginFields shadow-lg',
        },        
    ]
};

const fields = [
    {
      id: 'username',
      label: 'User Name',
      type: 'text',
      name: 'username',
      value: '',
      placeholder: 'User ID',
      classNames: 'usernametb',
      validations: [
        {
          type: 'required',
          params: ['This field is required'],
        },
      ],
    },
    {
      id: 'password',
      label: 'Password',
      type: 'password',
      name: 'password',
      value: '',
      placeholder: 'Password',
      classNames: 'usernametb',
      validations: [
        {
          type: 'required',
          params: ['This field is required'],
        },
      ],
    },
    {
      id: 'userId',
      classNames: 'usernametb',
      type: 'select',
      name: 'userId',
      value: [],
      options: [
        { value: '400/US01-000005673', label: '400/US01-000005673)' },
        { value: '400/US01-000005674', label: '400/US01-000005674' },
        { value: '400/US01-000005675', label: '400/US01-000005675' },
      ],
      validations: [
        {
          type: 'required',
          params: ['This field is required'],
        },
      ],
    },
];

function onFormSubmit() {
  // alert("Dynamic Forms")
}

export default {
  title: 'Navbar',
  component: Navbar,
};

const yepSchema = fields.reduce(createYupSchema, {});
const validateSchema = Yup.object().shape(yepSchema);

export const Navbar1 = () => {
  return (
    <div>
       <DynamicForm
        form={form}
        fields={fields}
        validation={validateSchema}
        onFormSubmit={onFormSubmit()}
        errorPosition="right"
        />
    </div>
  )
};

Navbar1.story = {
  name: 'Navbar',
};

export const SideBar = () => {
  return (
    <div>
       <DynamicForm
        form={form}
        fields={fields}
        validation={validateSchema}
        onFormSubmit={onFormSubmit()}
        errorPosition="right"
        />
    </div>
  )
};

SideBar.story = {
  name: 'Side bar',
};

export const SideBarXS = () => {
  return (
    <div>
       <DynamicForm
        form={form}
        fields={fields}
        validation={validateSchema}
        onFormSubmit={onFormSubmit()}
        errorPosition="right"
        />
    </div>
  )
};

SideBarXS.story = {
  name: 'Side bar XS',
};

export const Header1 = () => {
  return (
    <div>
       <Header/>
    </div>
  )
};

Header1.story = {
  name: 'Header',
};

export const Footer1 = () => {
  return (
    <div>
       <Footer />
    </div>
  )
};

Footer1.story = {
  name: 'Footer',
};